#!/usr/bin/env python

import unittest
from path import *
from hostinfo import *

simplexml = """<?xml version='1.0' encoding='utf-8' ?>
<host xmlns='http://psha.org.ru/ns/mnet' uuid='test'>
	<detail attr='val'>yohoho</detail>
	<!--<tag/>-->
</host>
"""

class HostInfoTestCase(unittest.TestCase):
	"Test case for hostinfo parsers"
	def check_imports(self):
		from xml.dom import minidom
		from StringIO import StringIO
		from xml.dom import ext
	def check_dump(self):
		d = Detail()
		d.value = "test"
		n = d.xml()
		d0 = Detail(xml = n)
		#print d.__dict__
		#print n
		#print d0.__dict__
		assert d.value.strip() == d0.value.strip(), "data corrupted"

	def check_2dump(self):
		from xml.dom import minidom, ext
		from StringIO import StringIO
		d0 = minidom.parseString(simplexml)
		h0 = HostInfo(xml = d0.childNodes[0])
		x1 = h0.xml()
		h1 = HostInfo(xml = x1)
		x2 = h1.xml()
		(d1, d2) = map (lambda x: minidom.Document(), [1, 2])
		d1.appendChild(x1)
		d2.appendChild(x2)
		(s1, s2) = map (lambda x: StringIO(), [1, 2])
		map (ext.PrettyPrint, [(d1, s1), (d2, s2)])
		assert s1.getvalue() == s2.getvalue(), "Double dump failed"

	def check_parse(self):
		from xml.dom import minidom

		d = minidom.parseString(simplexml)
		h = HostInfo(xml = d.childNodes[0])
		d0 = minidom.Document()
		d0.appendChild(h.xml())
		#print h.xml()
		#print h.__dict__
		#print h.detail.__dict__

		from StringIO import StringIO
		from xml.dom import ext
		ss = StringIO()
		ext.PrettyPrint(d0, ss)
		#print ss.getvalue()

	def check_load(self):
		from xml.dom import minidom

		d = minidom.parse("test.xml")
		h = HostMap(xml = d.childNodes[1])
		d0 = minidom.Document()
		d0.appendChild(h.xml())
		#print h.xml()
		#print h.__dict__
		#print h.detail.__dict__

		from StringIO import StringIO
		from xml.dom import ext
		ss = StringIO()
		ext.PrettyPrint(d0, ss)
		#print ss.getvalue()

	def check_load_state(self):
		from xml.dom import minidom

		d = minidom.parse("states.xml")
		h = StateMap(xml = d.childNodes[1])
		d0 = minidom.Document()
		d0.appendChild(h.xml())
		#print h.xml()
		#print h.__dict__
		#print h.detail.__dict__

		from StringIO import StringIO
		from xml.dom import ext
		ss = StringIO()
		ext.PrettyPrint(d0, ss)
		#print ss.getvalue()

def makeTestSuite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(HostInfoTestCase, "check"))
    return suite

defaultTest = makeTestSuite

def main():
    unittest.main(defaultTest="defaultTest")


if __name__ == "__main__" : main()


